Learn R Programming

ranger (version 0.6.0)

importance_pvalues: ranger variable importance p-values

Description

Compute variable importance with p-values.

Usage

importance_pvalues(x, method = c("janitza", "altmann"), num.permutations = 100, formula = NULL, data = NULL, ...)

Arguments

x
ranger or holdoutRF object.
method
Method to compute p-values. Use "janitza" for the method by Janitza et al. (2015) or "altmann" for the non-parametric method by Altmann et al. (2010).
num.permutations
Number of permutations. Used in the "altmann" method only.
formula
Object of class formula or character describing the model to fit. Used in the "altmann" method only.
data
Training data of class data.frame or matrix. Used in the "altmann" method only.
...
Further arguments passed to ranger(). Used in the "altmann" method only.

Value

Variable importance and p-values.

References

Janitza, S., Celik, E. & Boulesteix, A.-L., (2015). A computationally fast variable importance test for random forest for high dimensional data, Technical Report 185, University of Munich, https://epub.ub.uni-muenchen.de/25587. Altmann, A., Tolosi, L., Sander, O. & Lengauer, T. (2010). Permutation importance: a corrected feature importance measure, Bioinformatics 26(10):1340-1347.

See Also

ranger